<?php

// ==========================================================================
// Constants
// ==========================================================================

// Activation server URL
define('LSERV_URL', 'https://activation.mandriva.com/');

// Installation UUID File
define('UUID_FILE', '/etc/pulse-licensing/installation_id');

// License Key files
define('LPUBKEY_FILE', '/etc/pulse-licensing/license.pub');
define('LPRIVATEKEY_FILE', '/etc/pulse-licensing/license');
define('LDATA_FILE', '/etc/pulse-licensing/license.dat');

// Licenced file
define('LICENSED_BIN', '/usr/sbin/pulse-licensed');

// Support SSH Keys
define('S_SSH_PUB_FILE', '/etc/mmc/plugins/support/id_rsa.pub');
define('S_SSH_PRIVATE_FILE', '/etc/mmc/plugins/support/id_rsa');

// OEM identifier
define('OEM_ID_FILE', '/etc/pulse-licensing/oem');

// ==========================================================================

function lserv_query($username, $password, $cmd, $options){
   
   $url = LSERV_URL . $cmd;
   
   // Setting headers
    $headers = array(
        'Accept: application/json',
        'Content-Type: application/json',
    );
    
    // Encoding options
    $data = json_encode($options);
    
    $handle = curl_init();

    curl_setopt($handle, CURLOPT_URL, $url);
    curl_setopt($handle, CURLOPT_HTTPHEADER, $headers);
    if ($username && $password)
      curl_setopt($handle, CURLOPT_USERPWD, $username . ":" . $password);
    curl_setopt($handle, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($handle, CURLOPT_SSL_VERIFYHOST, false);
    curl_setopt($handle, CURLOPT_SSL_VERIFYPEER, false);
     
    curl_setopt($handle, CURLOPT_CUSTOMREQUEST, 'GET');
    curl_setopt($handle, CURLOPT_POSTFIELDS, $data);
     
    $response = curl_exec($handle);
    $code = curl_getinfo($handle, CURLINFO_HTTP_CODE);
       
    curl_close($handle);
    
    if ($code != 200){
         // Shifting 0 code
         if ($code == 0)
             $code = 1000;
             
         // debug
        return (object) array('codereturn' => $code);
    }
    else{
        return json_decode($response);
    }
    
}

function get_oem_id(){
   if (file_exists(OEM_ID_FILE)) return trim(file_get_contents(OEM_ID_FILE));
   return False;
}


function get_installation_uuid(){
   return trim(file_get_contents(UUID_FILE));
}

function get_license_public_key(){
   return trim(file_get_contents(LPUBKEY_FILE));
}

function get_support_ssh_public_key(){
   return file_get_contents(S_SSH_PUB_FILE);
}

function get_license_data(){
   return trim(file_get_contents(LDATA_FILE));
}

function get_lisense_data(){

   // Checking if license is valid or not and return license information
   $cmd = sprintf('%s -G %s -l %s -p %s -i', LICENSED_BIN, UUID_FILE, LDATA_FILE, LPRIVATEKEY_FILE);
   exec($cmd, $output, $exit_code);
   
   if ($exit_code == 0){
      $result = json_decode(implode("\n",$output), TRUE);
      // If result is not empty, return it
      return $result;
   }
   else
      return FALSE;

}

function set_license_data($data){
   if (file_put_contents(LDATA_FILE, trim($data)) === FALSE)
      return FALSE;
   
   $ldata = get_lisense_data();

   if ($ldata){
      return $ldata;
   }
   else{
      // Else => Clear license.dat file
      file_put_contents(LDATA_FILE, '');
      return FALSE;
   } 
   
}

function delete_license_public_key(){
   unlink(LPUBKEY_FILE);
}

function p2d_call($request){
   $cmd = "/usr/sbin/pulse2-debug -c '$request'";
   exec($cmd, $output, $exit_code);
   if ($exit_code == 0)
      return trim(implode("\n",$output));
   else
      die('Unable to reach mmc-agent, call your support.');
}

function update_debian_source_list(){
   return p2d_call('pulse2.updateDebianSourceList()');
}

function post_activate_actions(){
   // Init support info data
   p2d_call('support.get_license_info()');
}

function post_activate_actions_full(){

   // this function is called after a succesful acivation
   
   // Write source.list for accessing updates
   update_debian_source_list();

   // Delete license public key (nomore needed)
   delete_license_public_key();
}

function generate_support_ssh_keys(){
     
   // If the key already exists, leaving
   if (file_exists(S_SSH_PRIVATE_FILE))
      return TRUE;
   
   $cmd = sprintf("/usr/bin/ssh-keygen -f %s -P ''", S_SSH_PRIVATE_FILE);
   exec($cmd, $output, $exit_code);
   
   return ($exit_code == 0);
}

?>
